@@ -808,10 +808,7 @@ namespace Tomboy
 
 			// Remove tags now, since a note with no tags has
 			// no "tags" element in the XML
-			foreach (Tag tag in Tags)
-			RemoveTag (tag);
-
-			DateTime date;
+			List<Tag> newTags = new List<Tag> ();
 
 			while (xml.Read ()) {
 				switch (xml.NodeType) {
@@ -824,35 +821,27 @@ namespace Tomboy
 						XmlContent = xml.ReadInnerXml ();
 						break;
 					case "last-change-date":
-						if (DateTime.TryParse (xml.ReadString (), out date))
-							data.Data.ChangeDate = date;
-						else
-							data.Data.ChangeDate = DateTime.Now;
+						data.Data.ChangeDate =
+						        XmlConvert.ToDateTime (xml.ReadString (), NoteArchiver.DATE_TIME_FORMAT);
 						break;
 					case "last-metadata-change-date":
-						if (DateTime.TryParse (xml.ReadString (), out date))
-							data.Data.MetadataChangeDate = date;
-						else
-							data.Data.MetadataChangeDate = DateTime.Now;
+						data.Data.MetadataChangeDate =
+						        XmlConvert.ToDateTime (xml.ReadString (), NoteArchiver.DATE_TIME_FORMAT);
 						break;
 					case "create-date":
-						if (DateTime.TryParse (xml.ReadString (), out date))
-							data.Data.CreateDate = date;
-						else
-							data.Data.CreateDate = DateTime.Now;
+						data.Data.CreateDate =
+						        XmlConvert.ToDateTime (xml.ReadString (), NoteArchiver.DATE_TIME_FORMAT);
 						break;
 					case "tags":
 						XmlDocument doc = new XmlDocument ();
 						List<string> tag_strings = ParseTags (doc.ReadNode (xml.ReadSubtree ()));
 						foreach (string tag_str in tag_strings) {
 							Tag tag = TagManager.GetOrCreateTag (tag_str);
-							AddTag (tag);
+							newTags.Add (tag);
 						}
 						break;
 					case "open-on-startup":
-						bool isStartup;
-						if (bool.TryParse (xml.ReadString (), out isStartup))
-							IsOpenOnStartup = isStartup;
+						IsOpenOnStartup = bool.Parse (xml.ReadString ());
 						break;
 					}
 					break;
@@ -861,6 +850,12 @@ namespace Tomboy
 
 			xml.Close ();
 
+			foreach (Tag oldTag in Tags)
+				if (!newTags.Contains (oldTag))
+				    RemoveTag (oldTag);
+			foreach (Tag newTag in newTags)
+				AddTag (newTag);
+
 			// Allow method caller to specify ChangeType (mostly needed by sync)
 			QueueSave (changeType);
 		}
@@ -1113,8 +1108,6 @@ namespace Tomboy
 	{
 		public const string CURRENT_VERSION = "0.3";
 
-		// NOTE: If this changes from a standard format, make sure to update
-		//       XML parsing to have a DateTime.TryParseExact
 		public const string DATE_TIME_FORMAT = "yyyy-MM-ddTHH:mm:ss.fffffffzzz";
 
 		static NoteArchiver instance = null;
@@ -1157,8 +1150,6 @@ namespace Tomboy
 			                                        System.Text.Encoding.UTF8);
 			XmlTextReader xml = new XmlTextReader (reader);
 			xml.Namespaces = false;
-			DateTime date;
-			int num;
 
 			while (xml.Read ()) {
 				switch (xml.NodeType) {
@@ -1176,42 +1167,31 @@ namespace Tomboy
 						note.Text = xml.ReadInnerXml ();
 						break;
 					case "last-change-date":
-						if (DateTime.TryParse (xml.ReadString (), out date))
-							note.ChangeDate = date;
-						else
-							note.ChangeDate = DateTime.Now;
+						note.ChangeDate =
+						        XmlConvert.ToDateTime (xml.ReadString (), DATE_TIME_FORMAT);
 						break;
 					case "last-metadata-change-date":
-						if (DateTime.TryParse (xml.ReadString (), out date))
-							note.MetadataChangeDate = date;
-						else
-							note.MetadataChangeDate = DateTime.Now;
+						note.MetadataChangeDate =
+						        XmlConvert.ToDateTime (xml.ReadString (), DATE_TIME_FORMAT);
 						break;
 					case "create-date":
-						if (DateTime.TryParse (xml.ReadString (), out date))
-							note.CreateDate = date;
-						else
-							note.CreateDate = DateTime.Now;
+						note.CreateDate =
+						        XmlConvert.ToDateTime (xml.ReadString (), DATE_TIME_FORMAT);
 						break;
 					case "cursor-position":
-						if (int.TryParse (xml.ReadString (), out num))
-							note.CursorPosition = num;
+						note.CursorPosition = int.Parse (xml.ReadString ());
 						break;
 					case "width":
-						if (int.TryParse (xml.ReadString (), out num))
-							note.Width = num;
+						note.Width = int.Parse (xml.ReadString ());
 						break;
 					case "height":
-						if (int.TryParse (xml.ReadString (), out num))
-							note.Height = num;
+						note.Height = int.Parse (xml.ReadString ());
 						break;
 					case "x":
-						if (int.TryParse (xml.ReadString (), out num))
-							note.X = num;
+						note.X = int.Parse (xml.ReadString ());
 						break;
 					case "y":
-						if (int.TryParse (xml.ReadString (), out num))
-							note.Y = num;
+						note.Y = int.Parse (xml.ReadString ());
 						break;
 					case "tags":
 						XmlDocument doc = new XmlDocument ();
@@ -1222,9 +1202,7 @@ namespace Tomboy
 						}
 						break;
 					case "open-on-startup":
-						bool isStartup;
-						if (bool.TryParse (xml.ReadString (), out isStartup))
-							note.IsOpenOnStartup = isStartup;
+						note.IsOpenOnStartup = bool.Parse (xml.ReadString ());
 						break;
 					}
 					break;
