@@ -753,10 +753,10 @@ namespace Tomboy
 			entry.Changed += OnFindEntryChanged;
 			entry.Activated += OnFindEntryActivated;
 			entry.Show ();
-			PackStart (entry, false, false, 0);
+			PackStart (entry, true, true, 0);
 
 			prev_button = new Gtk.Button (Catalog.GetString ("_Previous"));
-			prev_button.Image = new Gtk.Image (Gtk.Stock.GoBack, Gtk.IconSize.Menu);
+			prev_button.Image = new Gtk.Arrow (Gtk.ArrowType.Left, Gtk.ShadowType.None);
 			prev_button.Relief = Gtk.ReliefStyle.None;
 			prev_button.Sensitive = false;
 			prev_button.FocusOnClick = false;
@@ -764,8 +764,8 @@ namespace Tomboy
 			prev_button.Show ();
 			PackStart (prev_button, false, false, 0);
 
-			next_button = new Gtk.Button (Catalog.GetString ("Find _Next"));
-			next_button.Image = new Gtk.Image (Gtk.Stock.GoForward, Gtk.IconSize.Menu);
+			next_button = new Gtk.Button (Catalog.GetString ("_Next"));
+			next_button.Image = new Gtk.Arrow (Gtk.ArrowType.Right, Gtk.ShadowType.None);
 			next_button.Relief = Gtk.ReliefStyle.None;
 			next_button.Sensitive = false;
 			next_button.FocusOnClick = false;
@@ -1184,6 +1184,12 @@ namespace Tomboy
 		Gtk.ImageMenuItem increase_indent;
 		Gtk.ImageMenuItem decrease_indent;
 
+		// There is a bug in GTK+ that lends to improperly themed Menus
+		// and MenuItems when you derive from one of those classes; this
+		// is an internal Menu that sits around to provide proper theme
+		// information to override on this derived Menu
+		Gtk.Menu theme_hack_menu;
+
 		// Active when the text size is indeterminable, such as when in
 		// the note's title line.
 		Gtk.RadioMenuItem hidden_no_size;
@@ -1363,6 +1369,12 @@ namespace Tomboy
 			Append (increase_indent);
 			Append (decrease_indent);
 			ShowAll ();
+
+			theme_hack_menu = new Menu ();
+			theme_hack_menu.Realize ();
+			theme_hack_menu.StyleSet += delegate {
+				ModifyBg (StateType.Normal, theme_hack_menu.Style.Background (StateType.Normal));
+			};
 		}
 
 		protected override void OnShown ()
