@@ -287,7 +287,8 @@ namespace Tomboy
 				"Sandy Armstrong <sanfordarmstrong@gmail.com>",
 				"Sebastian Rittau <srittau@jroger.in-berlin.de>",
 				"Kevin Kubasik <kevin@kubasik.net>",
-				"Stefan Schweizer <steve.schweizer@gmail.com>"
+				"Stefan Schweizer <steve.schweizer@gmail.com>",
+				"Benjamin Podszun <benjamin.podszun@gmail.com>"
 			};
 
 			string [] documenters = new string [] {
@@ -307,7 +308,8 @@ namespace Tomboy
 			about.Version = Defines.VERSION;
 			about.Logo = GuiUtils.GetIcon ("tomboy", 48);
 			about.Copyright =
-			        Catalog.GetString ("Copyright \xa9 2004-2007 Alex Graveley");
+			        Catalog.GetString ("Copyright \xa9 2004-2007 Alex Graveley\n" +
+				                   "Copyright \xa9 2004-2009 Others\n");
 			about.Comments = Catalog.GetString ("A simple and easy to use desktop " +
 			                                    "note-taking application.");
 			Gtk.AboutDialog.SetUrlHook (delegate (Gtk.AboutDialog dialog, string link) {
